summaryrefslogtreecommitdiff
path: root/contrib
diff options
context:
space:
mode:
authorTim Kientzle <kientzle@gmail.com>2012-01-07 19:45:39 -0500
committerTim Kientzle <kientzle@gmail.com>2012-01-07 19:45:39 -0500
commit471e1846ad5ec68fff875d1ef0850ca580eec1fd (patch)
tree8149281d056da7f2aa0356ae499a0462151f0b8b /contrib
parentfca74c84c2d77ccb79d58c0632ca64eafa420ba1 (diff)
downloadlibarchive-471e1846ad5ec68fff875d1ef0850ca580eec1fd.tar.gz
Last of Ulrich Spoerlein's spelling fixes.
SVN-Revision: 4094
Diffstat (limited to 'contrib')
-rw-r--r--contrib/psota-benchmark/results.txt2
-rwxr-xr-xcontrib/psota-benchmark/tcp.sh8
2 files changed, 5 insertions, 5 deletions
diff --git a/contrib/psota-benchmark/results.txt b/contrib/psota-benchmark/results.txt
index f557a62e..2d364c55 100644
--- a/contrib/psota-benchmark/results.txt
+++ b/contrib/psota-benchmark/results.txt
@@ -1,4 +1,4 @@
-ODP: [Bug-tar] GNU tar, star and BSD tar speed comparision +new script
+ODP: [Bug-tar] GNU tar, star and BSD tar speed comparison +new script
Jan Psota
Thu, 25 Oct 2007 06:51:13 -0700
diff --git a/contrib/psota-benchmark/tcp.sh b/contrib/psota-benchmark/tcp.sh
index 80971900..3f630732 100755
--- a/contrib/psota-benchmark/tcp.sh
+++ b/contrib/psota-benchmark/tcp.sh
@@ -1,9 +1,9 @@
#!/bin/sh
# tar comparision program
# 2007-10-25 Jan Psota
n=3 # number of repetitions
-TAR="bsdtar gnutar star" # TApeArchivers to compare
+TAR="bsdtar gnutar star" # Tape archivers to compare
OPT=("" "--seek" "-no-fsync")
pax="--format=pax" # comment out for defaults
OPN=(create list extract compare) # operations
@@ -16,9 +16,9 @@ test $# -ge 2 || {
[where_to_extract_it]
TCP, version $version
-TCP stands for Tar Comparision Program here.
+TCP stands for Tar Comparison Program here.
It currently compares: BSD tar (bsdtar), GNU tar (gnutar) and star in archive
-creation, listing, extraction and archive-to-extracted comparision.
+creation, listing, extraction and archive-to-extracted comparison.
Tcp prints out best time of n=$n repetitions.
Tcp creates temporary archive named tcp.tar with $pax and some native
@@ -1,9 +1,9 @@
#!/bin/sh
-# tar comparision program
+# tar comparison program
# 2007-10-25 Jan Psota
n=3 # number of repetitions